@@ -156,6 +156,28 @@ async def gerror(self, given_client: AsyncIOClient = None, {params_fields_str})
     return f"{get_str}\n{gerror_str}"
 
 
+def build_include_fields_function(
+    node_resolver_name: str,
+    appendix_properties: set[str],
+    computed_properties: set[str],
+) -> str:
+    field_names = sorted({*appendix_properties, *computed_properties})
+    names_params = ", ".join([f"{name}: bool = False" for name in field_names])
+    logic_strs = "\n".join(
+        [
+            f'if {field_name} is True: fields_to_include.add("{field_name}")'
+            for field_name in field_names
+        ]
+    )
+    s = f"""
+def include_fields(self, {names_params}) -> {node_resolver_name}:
+    fields_to_include: set[str] = set()
+{indent_lines(logic_strs)}
+    return super().include_fields(*fields_to_include)
+    """
+    return s
+
+
 def build_filter_functions_str(node_name: str, conversion_map: T.Dict[str, dict]):
     field_names = sorted(conversion_map.keys())
     params_fields_str = ", ".join(
@@ -550,6 +572,11 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
     resolver_get_functions_str = build_get_functions_str(
         node_name=object_type.node_name, exclusive_field_names=exclusive_fields
     )
+    resolver_include_fields_str = build_include_fields_function(
+        node_resolver_name=node_resolver_name,
+        appendix_properties=appendix_properties,
+        computed_properties=computed_properties,
+    )
     resolver_filter_functions_str = build_filter_functions_str(
         node_name=object_type.node_name, conversion_map=node_edgedb_conversion_map
     )
@@ -571,6 +598,7 @@ def {prop.name}(self, {prop.name}: {type_str}) -> None:
         resolver_link_functions_str,
         resolver_get_functions_str,
         resolver_filter_functions_str,
+        resolver_include_fields_str,
     ]
     resolver_inner_str = "\n".join(resolver_inner_strs)
     resolver_s = f"class {node_resolver_name}(Resolver[{object_type.node_name}]):\n{indent_lines(resolver_inner_str)}"
